@@ -20,6 +20,9 @@
  * Boston, MA 02111-1307, USA.
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
 #include <gr_fir_ccf_x86.h>
 #include <fcomplex_dotprod_x86.h>
 
