@@ -20,6 +20,9 @@
  * Boston, MA 02111-1307, USA.
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
 #include <gr_fir_scc.h>
 
 gr_fir_scc::~gr_fir_scc ()
