@@ -33,7 +33,7 @@
 #include <qa_gr_fir_scc.h>
 #include <qa_gr_firdes.h>
 #include <qa_dotprod.h>
-#include <qa_gr_mmse_fir_interpolator.h>
+#include <qa_gri_mmse_fir_interpolator.h>
 
 CppUnit::TestSuite *
 qa_filter::suite ()
@@ -41,7 +41,7 @@ qa_filter::suite ()
   CppUnit::TestSuite	*s = new CppUnit::TestSuite ("filter");
 
   s->addTest (qa_dotprod_suite ());
-  s->addTest (qa_gr_mmse_fir_interpolator::suite ());
+  s->addTest (qa_gri_mmse_fir_interpolator::suite ());
   s->addTest (qa_gr_fir_fff::suite ());
   s->addTest (qa_gr_fir_ccc::suite ());
   s->addTest (qa_gr_fir_fcc::suite ());
