@@ -21,6 +21,9 @@
  */
 
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
 #include <gr_lfsr_32k_source_s.h>
 #include <gr_io_signature.h>
 #include <stdexcept>
