@@ -107,8 +107,9 @@ gr_pll_carriertracking_cc::work (int noutput_items,
     else if (d_freq < d_min_freq)
       d_freq = d_min_freq;
     gr_sincosf(d_phase,&t_imag,&t_real);
-    optr[i] = iptr[i] * gr_complex(t_real,t_imag);
-    d_locksig = (optr[i]*gr_complex(t_real,-t_imag)).real();
+    optr[i] = gr_complex(t_real,t_imag);
+    d_locksig = d_locksig * (1.0 - d_alpha) + d_alpha*(iptr[i].real() * t_real + iptr[i].imag() * t_imag);
+    
     if ((d_squelch_enable) && !lock_detector())
       optr[i] = 0;
   }
