@@ -20,7 +20,7 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#ifndef HAVE_CONFIG_H
+#ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
 
