@@ -32,6 +32,15 @@
 #include <fcntl.h>
 #include <stdexcept>
 
+// win32 (mingw/msvc) specific
+#ifdef HAVE_IO_H
+#include <io.h>
+#endif
+#ifdef O_BINARY
+#define	OUR_O_BINARY O_BINARY
+#else
+#define	OUR_O_BINARY 0
+#endif
 // should be handled via configure
 #ifdef O_LARGEFILE
 #define	OUR_O_LARGEFILE	O_LARGEFILE
@@ -48,7 +57,7 @@ gr_file_source::gr_file_source (size_t itemsize, const char *filename, bool repe
   // we use "open" to use to the O_LARGEFILE flag
   
   int fd;
-  if ((fd = open (filename, O_RDONLY | OUR_O_LARGEFILE)) < 0){
+  if ((fd = open (filename, O_RDONLY | OUR_O_LARGEFILE | OUR_O_BINARY)) < 0){
     perror (filename);
     throw std::runtime_error ("can't open file");
   }
