@@ -2,6 +2,7 @@
 //				Package : omnithread
 // omnithread.h			Created : 7/94 tjr
 //
+//    Copyright (C) 2006 Free Software Foundation, Inc.
 //    Copyright (C) 1994,1995,1996, 1997 Olivetti & Oracle Research Laboratory
 //
 //    This file is part of the omnithread library
@@ -145,6 +146,7 @@ class omni_thread;
 
 #if (!defined(OMNI_MUTEX_IMPLEMENTATION)        || \
      !defined(OMNI_MUTEX_LOCK_IMPLEMENTATION)   || \
+     !defined(OMNI_MUTEX_TRYLOCK_IMPLEMENTATION)|| \
      !defined(OMNI_MUTEX_UNLOCK_IMPLEMENTATION) || \
      !defined(OMNI_CONDITION_IMPLEMENTATION)    || \
      !defined(OMNI_SEMAPHORE_IMPLEMENTATION)    || \
@@ -186,6 +188,10 @@ public:
 
     inline void lock(void)    { OMNI_MUTEX_LOCK_IMPLEMENTATION   }
     inline void unlock(void)  { OMNI_MUTEX_UNLOCK_IMPLEMENTATION }
+    inline int trylock(void)  { return OMNI_MUTEX_TRYLOCK_IMPLEMENTATION }
+	// if mutex is unlocked, lock it and return 1 (true).
+	// If it's already locked then return 0 (false).
+
     inline void acquire(void) { lock(); }
     inline void release(void) { unlock(); }
 	// the names lock and unlock are preferred over acquire and release
@@ -285,14 +291,15 @@ OMNI_THREAD_EXPOSE:
 
 ///////////////////////////////////////////////////////////////////////////
 //
-// Counting semaphore
+// Counting (or binary) semaphore
 //
 ///////////////////////////////////////////////////////////////////////////
 
 class _OMNITHREAD_NTDLL_ omni_semaphore {
 
 public:
-    omni_semaphore(unsigned int initial = 1);
+    // if max_count == 1, you've got a binary semaphore.
+    omni_semaphore(unsigned int initial = 1, unsigned int max_count = 0x7fffffff);
     ~omni_semaphore(void);
 
     void wait(void);
