@@ -60,6 +60,23 @@ class gr_block {
   gr_io_signature_sptr output_signature () const { return d_output_signature; }
   long unique_id () const { return d_unique_id; }
 
+  /*!
+   * Assume block computes y_i = f(x_i, x_i-1, x_i-2, x_i-3...)
+   * History is the number of x_i's that are examined to produce one y_i.
+   * This comes in handy for FIR filters, where we use history to
+   * ensure that our input contains the appropriate "history" for the
+   * filter.   History should be equal to the number of filter taps.
+   */
+  unsigned history () const { return d_history; }
+  void  set_history (unsigned history) { d_history = history; }
+  
+  /*!
+   * \brief return true if this block has a fixed input to output rate
+   *
+   * If true, then fixed_rate_in_to_out and fixed_rate_out_to_in may be called.
+   */
+  bool fixed_rate() const { return d_fixed_rate; }
+
   // ----------------------------------------------------------------
   //		override these to define your behavior
   // ----------------------------------------------------------------
@@ -111,6 +128,21 @@ class gr_block {
    */
   virtual bool check_topology (int ninputs, int noutputs);
 
+  /*!
+   * \brief Called to enable drivers, etc for i/o devices.
+   *
+   * This allows a block to enable an associated driver to begin
+   * transfering data just before we start to execute the scheduler.
+   * The end result is that this reduces latency in the pipeline when
+   * dealing with audio devices, usrps, etc.
+   */
+  virtual bool start();
+
+  /*!
+   * \brief Called to disable drivers, etc for i/o devices.
+   */
+  virtual bool stop();
+
   // ----------------------------------------------------------------
 
   /*!
@@ -149,6 +181,25 @@ class gr_block {
    */
   double relative_rate () const	{ return d_relative_rate; }
 
+  /*
+   * The following two methods provide special case info to the
+   * scheduler in the event that a block has a fixed input to output
+   * ratio.  gr_sync_block, gr_sync_decimator and gr_sync_interpolator
+   * override these.  If you're fixed rate, subclass one of those.
+   */
+  /*!
+   * \brief Given ninput samples, return number of output samples that will be produced.
+   * N.B. this is only defined if fixed_rate returns true.
+   * Generally speaking, you don't need to override this.
+   */
+  virtual int fixed_rate_ninput_to_noutput(int ninput);
+
+  /*!
+   * \brief Given noutput samples, return number of input samples required to produce noutput.
+   * N.B. this is only defined if fixed_rate returns true.
+   * Generally speaking, you don't need to override this.
+   */
+  virtual int fixed_rate_noutput_to_ninput(int noutput);
 
   // ----------------------------------------------------------------------------
 
@@ -161,6 +212,9 @@ class gr_block {
   double		d_relative_rate;	// approx output_rate / input_rate
   gr_block_detail_sptr	d_detail;		// implementation details
   long			d_unique_id;		// convenient for debugging
+  unsigned		d_history;
+  bool			d_fixed_rate;
+
   
  protected:
 
@@ -178,6 +232,8 @@ class gr_block {
     d_output_signature = iosig;
   }
 
+  void set_fixed_rate(bool fixed_rate){ d_fixed_rate = fixed_rate; }
+
   // These are really only for internal use, but leaving them public avoids
   // having to work up an ever-varying list of friends
 
