@@ -28,6 +28,10 @@
 #include <unistd.h>
 #include <stdio.h>
 
+#if defined(_WIN32) && defined(HAVE_GETPAGESIZE)
+extern "C" size_t getpagesize(void);
+#endif
+
 int
 gr_pagesize ()
 {
