@@ -38,20 +38,18 @@ class wfm_rcv_pll(gr.hier_block):
         @param audio_decimation: how much to decimate demod_rate to get to audio.
         @type audio_decimation: integer
         """
-        volume = 20.
 
-        max_dev = 75e3
-        fm_demod_gain = demod_rate/(2*math.pi*max_dev)
+        bandwidth = 200e3
         audio_rate = demod_rate / audio_decimation
-        
+
 
         # We assign to self so that outsiders can grab the demodulator 
         # if they need to.  E.g., to plot its output.
         #
         # input: complex; output: float
-        alpha = max_dev * 2.0 * math.pi / (2*demod_rate)
+        alpha = 0.25*bandwidth * math.pi / demod_rate
         beta = alpha * alpha / 4.0
-        max_freq = 2.0*math.pi*150e3/demod_rate
+        max_freq = 2.0*math.pi*100e3/demod_rate
             
         self.fm_demod = gr.pll_freqdet_cf (alpha,beta,max_freq,-max_freq)
 
@@ -63,7 +61,7 @@ class wfm_rcv_pll(gr.hier_block):
         width_of_transition_band = audio_rate / 32
         audio_coeffs = gr.firdes.low_pass (1.0 ,         # gain
                                            demod_rate,      # sampling rate
-                                           audio_rate/2 - width_of_transition_band,
+                                           15000 ,
                                            width_of_transition_band,
                                            gr.firdes.WIN_HAMMING)
         # input: float; output: float
@@ -73,10 +71,10 @@ class wfm_rcv_pll(gr.hier_block):
             # We pick off the negative frequency half because we want to base band by it!
             ##  NOTE  THIS WAS HACKED TO OFFSET INSERTION LOSS DUE TO DEEMPHASIS
 
-            stereo_carrier_filter_coeffs = gr.firdes.complex_band_pass(20.0,
+            stereo_carrier_filter_coeffs = gr.firdes.complex_band_pass(10.0,
                                                                    demod_rate,
-                                                                   -19100,
-                                                                   -18900,
+                                                                   -19020,
+                                                                   -18980,
                                                                    width_of_transition_band,
                                                                    gr.firdes.WIN_HAMMING)
             
@@ -86,10 +84,10 @@ class wfm_rcv_pll(gr.hier_block):
 
             # Pick off the double side band suppressed carrier Left-Right audio. It is attenuated 10 dB so apply 10 dB gain
 
-            stereo_dsbsc_filter_coeffs = gr.firdes.complex_band_pass(30.0,
+            stereo_dsbsc_filter_coeffs = gr.firdes.complex_band_pass(20.0,
                                                                      demod_rate,
-                                                                     38000-audio_rate/2,
-                                                                     38000+audio_rate/2,
+                                                                     38000-15000/2,
+                                                                     38000+15000/2,
                                                                      width_of_transition_band,
                                                                      gr.firdes.WIN_HAMMING)
             #print "len stereo dsbsc filter = ",len(stereo_dsbsc_filter_coeffs)
@@ -101,13 +99,40 @@ class wfm_rcv_pll(gr.hier_block):
             # carrier is twice the picked off carrier so arrange to do a commplex multiply
 
             self.stereo_carrier_generator = gr.multiply_cc();
-            alpha = 5 * 2.0 * math.pi / (2*audio_rate)
+
+            # Pick off the rds signal
+
+            stereo_rds_filter_coeffs = gr.firdes.complex_band_pass(30.0,
+                                                                     demod_rate,
+                                                                     57000 - 1500,
+                                                                     57000 + 1500,
+                                                                     width_of_transition_band,
+                                                                     gr.firdes.WIN_HAMMING)
+            #print "len stereo dsbsc filter = ",len(stereo_dsbsc_filter_coeffs)
+            #print "stereo dsbsc filter ", stereo_dsbsc_filter_coeffs
+            # construct overlap add filter system from coefficients for stereo carrier
+
+            self.stereo_carrier_filter = gr.fir_filter_fcc(audio_decimation, stereo_carrier_filter_coeffs)
+	    self.rds_signal_filter = gr.fir_filter_fcc(audio_decimation, stereo_rds_filter_coeffs)
+
+
+
+
+
+
+	    self.rds_carrier_generator = gr.multiply_cc();
+	    self.rds_signal_generator = gr.multiply_cc();
+	    self_rds_signal_processor = gr.null_sink(gr.sizeof_gr_complex);
+
+
+
+            alpha = 5 * 0.25 * math.pi / (audio_rate)
             beta = alpha * alpha / 4.0
-            max_freq = -2.0*math.pi*18995/audio_rate;
-            min_freq = -2.0*math.pi*19005/audio_rate;
+            max_freq = -2.0*math.pi*18990/audio_rate;
+            min_freq = -2.0*math.pi*19010/audio_rate;
             
-            #self.stereo_carrier_generator2 = gr.pll_carriertracking_cc();
-            #self.stereo_carrier_generator2.squelch_enable(True);
+            self.stereo_carrier_pll_recovery = gr.pll_carriertracking_cc(alpha,beta,max_freq,min_freq);
+            self.stereo_carrier_pll_recovery.squelch_enable(False);
             
 
             # set up mixer (multiplier) to get the L-R signal at baseband
@@ -126,9 +151,9 @@ class wfm_rcv_pll(gr.hier_block):
         if 1:
 
             # send the real signal to complex filter to pick off the carrier and then to one side of a multiplier
-            fg.connect (self.fm_demod,self.stereo_carrier_filter, (self.stereo_carrier_generator,0))
+            fg.connect (self.fm_demod,self.stereo_carrier_filter,self.stereo_carrier_pll_recovery, (self.stereo_carrier_generator,0))
             # send the already filtered carrier to the otherside of the carrier
-            fg.connect (self.stereo_carrier_filter, (self.stereo_carrier_generator,1))
+            fg.connect (self.stereo_carrier_pll_recovery, (self.stereo_carrier_generator,1))
             # the resulting signal from this multiplier is the carrier with correct phase but at -38000 Hz.
 
             # send the new carrier to one side of the mixer (multiplier)
@@ -143,6 +168,17 @@ class wfm_rcv_pll(gr.hier_block):
             #take the same real part of the DSBSC baseband signal and send it to negative side of a subtracter
             fg.connect (self.LmR_real,(self.Make_Right,1))
 
+	    # Make rds carrier by taking the squared pilot tone and multiplying by pilot tone
+	    fg.connect (self.stereo_basebander,(self.rds_carrier_generator,0))
+            fg.connect (self.stereo_carrier_pll_recovery,(self.rds_carrier_generator,1)) 
+	    # take signal, filter off rds,  send into mixer 0 channel
+	    fg.connect (self.fm_demod,self.rds_signal_filter,(self.rds_signal_generator,0))
+            # take rds_carrier_generator output and send into mixer 1 channel
+	    fg.connect (self.rds_carrier_generator,(self.rds_signal_generator,1))
+	    # send basebanded rds signal and send into "processor" which for now is a null sink
+	    fg.connect (self.rds_signal_generator,self_rds_signal_processor)
+	    
+
         if 1:
             # pick off the audio, L+R that is what we used to have and send it to the summer
             fg.connect(self.fm_demod, self.audio_filter, (self.Make_Left, 1))
