@@ -21,47 +21,50 @@
 
 from gnuradio.gr.exceptions import *
 from gnuradio_swig_python import single_threaded_scheduler, sts_pyrun
-import threading
+import gr_threading as _threading
+#import threading as _threading
 
-class scheduler_thread (threading.Thread):
-    def __init__ (self, sts):
-        threading.Thread.__init__ (self)
+class scheduler_thread(_threading.Thread):
+    def __init__(self, sts):
+        _threading.Thread.__init__(self)
         self.sts = sts
-    def run (self):
+    def run(self):
         # Invoke the single threaded scheduler's run method
         #
         # Note that we're in a new thread, and that sts_pyrun
         # releases the global interpreter lock.  This has the
         # effect of evaluating the graph in parallel to the
         # main line control code.
-        sts_pyrun (self.sts)  
+        sts_pyrun(self.sts)  
         self.sts = None
         
-class scheduler (object):
-    def __init__ (self, fg):
-        graphs = fg.partition_graph (fg.blocks)
-        # print "@@@ # graphs = %d" % (len (graphs))
+class scheduler(object):
+    def __init__(self, fg):
+        graphs = fg.partition_graph(fg.blocks)
+        # print "@@@ # graphs = %d" % (len(graphs))
         
         self.state = []
         
         for g in graphs:
-            list_of_blocks = [x.block () for x in g]
-            sts = single_threaded_scheduler (list_of_blocks)
-            thread = scheduler_thread (sts)
-            thread.setDaemon (1)
-            self.state.append ((sts, thread))
+            list_of_blocks = [x.block() for x in g]
+            sts = single_threaded_scheduler(list_of_blocks)
+            thread = scheduler_thread(sts)
+            thread.setDaemon(1)
+            self.state.append((sts, thread))
 
-    def start (self):
+    def start(self):
         for (sts, thread) in self.state:
-            thread.start ()
+            thread.start()
 
-    def stop (self):
+    def stop(self):
         for (sts, thread) in self.state:
-            sts.stop ()
-        for (sts, thread) in self.state:
-            thread.join ()
+            sts.stop()
+        self.wait()
 
-    def wait (self):
+    def wait(self):
         for (sts, thread) in self.state:
-            thread.join ()
-            
+            timeout = 0.100
+            while True:
+                thread.join(timeout)
+                if not thread.isAlive():
+                    break
