@@ -35,7 +35,7 @@ function v = read_int_binary (filename, count)
     count = Inf;
   endif;
 
-  f = fopen (filename, "r");
+  f = fopen (filename, "rb");
   if (f < 0)
     v = 0;
   else
