@@ -30,7 +30,7 @@ function v = write_short_binary (data, filename)
     usage (m);
   endif;
 
-  f = fopen (filename, "w");
+  f = fopen (filename, "wb");
   if (f < 0)
     v = 0;
   else
